@@ -169,6 +169,11 @@ public class ParseCamt05200105 extends AbstractCamtParser
         
         // ditto
         EntryTransaction7 tx = txList.get(0);
+
+        // Ist es eine Rueckbuchung?
+        boolean rueckbuchung = tx.getRtrInf() != null && tx.getRtrInf().getRsn() != null && tx.getRtrInf().getRsn().getCd() != null && tx.getRtrInf().getRsn().getCd().length() > 0;
+        if (rueckbuchung) // Bei Rueckbuchung tauschen wir Creditor und Debitor
+          haben = !haben;
         
         ////////////////////////////////////////////////////////////////////////
         // Buchungs-ID
